@@ -18,11 +18,7 @@ pub fn histogram_with_type() {
 #[test]
 pub fn histogram_with_literal_and_tags() {
     let mock = mocks::histogram_mock("test", "test_value", &["added:tag", "env:test"]);
-    Datadog::new(mock, true, ["env:test"]).histogram(
-        "test",
-        "test_value",
-        vec!["added:tag".to_string()],
-    );
+    Datadog::new(mock, true, ["env:test"]).histogram("test", "test_value", vec!["added:tag".to_string()]);
 }
 
 #[test]
@@ -34,3 +30,29 @@ pub fn histogram_with_type_and_tags() {
         vec!["added:tag".to_string()],
     );
 }
+
+#[test]
+#[cfg(feature = "noop")]
+pub fn macro_histogram_with_literal() {
+    prima_datadog::histogram!("test", "test_value");
+}
+
+#[test]
+#[cfg(feature = "noop")]
+pub fn macro_histogram_with_type() {
+    use common::TestEvent;
+    prima_datadog::histogram!(TestEvent::Test1, "test_value");
+}
+
+#[test]
+#[cfg(feature = "noop")]
+pub fn macro_histogram_with_literal_and_tags() {
+    prima_datadog::histogram!("test", "test_value"; "added" => "tag");
+}
+
+#[test]
+#[cfg(feature = "noop")]
+pub fn macro_histogram_with_type_and_tags() {
+    use common::{TestEvent, TestEvent2};
+    prima_datadog::histogram!(TestEvent::Test1, "test_value"; "added" => TestEvent2::Test2);
+}
